get_payload

Function get_payload 

pub fn get_payload(
    body: Bytes,
    content_type: &MediaType,
    query_params: &QueryParams,
    action: &Action,
) -> Result<(Option<Payload>, HashSet<CompactString>), Error>
Parse the request body into a Payload based on content type and action.

Parse and validate the request payload.

Returns: (Option<Payload>, columns) where columns is the set of column names derived from either the payload keys or the &columns parameter.