Datasource

Struct Datasource 

pub struct Datasource {
    pub name: String,
    pub backend: Arc<dyn DatabaseBackend>,
    pub dialect: Arc<dyn SqlDialect>,
    pub config: AppConfig,
    pub version: DbVersion,
}
A single database datasource with its backend, dialect, config, and version.

Fields

name: String

Profile name used for Accept-Profile / Content-Profile routing.

backend: Arc<dyn DatabaseBackend>dialect: Arc<dyn SqlDialect>config: AppConfigversion: DbVersion

Implementations

Source

impl Datasource

pub fn new( name: impl Into<String>, backend: Arc<dyn DatabaseBackend>, dialect: Arc<dyn SqlDialect>, config: AppConfig, version: DbVersion, ) -> Self

Create a datasource from its parts.

pub async fn into_state(self) -> Result<AppState, Error>

Build an AppState and load the schema cache for this datasource.