JsPathExp

Enum JsPathExp 

pub enum JsPathExp {
    Key(CompactString),
    Index(usize),
}
JSON path expression for accessing JWT claims

Used to configure how to extract the role from JWT claims.

Examples

  • .role[Key("role")]
  • .realm_access.roles[0][Key("realm_access"), Key("roles"), Index(0)]

Variants



Key(CompactString)

Object key access: .key



Index(usize)

Array index access: [0]

Implementations

Source

impl JsPathExp

pub fn is_key(&self) -> bool

Check if this is a key expression

pub fn is_index(&self) -> bool

Check if this is an index expression

pub fn as_key(&self) -> Option<&str>

Get the key if this is a Key variant

pub fn as_index(&self) -> Option<usize>

Get the index if this is an Index variant