pub struct ReadPlanTree {
pub node: ReadPlan,
pub forest: Vec<ReadPlanTree>,
}Expand description
A tree of read plans (rose tree)
Each node represents a table/view to read from, with children representing embedded (joined) relations.
Fields
node: ReadPlanThis node’s read plan
forest: Vec<ReadPlanTree>Child read plans (embedded relations)
Implementations
Sourceimpl ReadPlanTree
impl ReadPlanTree
Sourcepub fn with_children(node: ReadPlan, forest: Vec<ReadPlanTree>) -> Self
pub fn with_children(node: ReadPlan, forest: Vec<ReadPlanTree>) -> Self
Create a tree with children
Sourcepub fn children(&self) -> &[ReadPlanTree]
pub fn children(&self) -> &[ReadPlanTree]
Get a reference to the children
Sourcepub fn children_mut(&mut self) -> &mut Vec<ReadPlanTree>
pub fn children_mut(&mut self) -> &mut Vec<ReadPlanTree>
Get mutable references to the children
Sourcepub fn iter(&self) -> ReadPlanTreeIter<'_> ⓘ
pub fn iter(&self) -> ReadPlanTreeIter<'_> ⓘ
Depth-first iteration over all nodes
Sourcepub fn node_count(&self) -> usize
pub fn node_count(&self) -> usize
Get the total number of nodes in the tree