Module db

Module db 

Database introspection trait

This module defines a trait for database introspection that can be mocked in tests. This allows unit testing schema cache logic without a real database.

Structs

ColumnJson
JSON structure for column data
ComputedFieldRow
Row type returned from computed fields query
ParamJson
JSON structure for routine parameter data
RelationshipRow
Row type returned from relationships query
ReturnTypeJson
JSON structure for return type data
RoutineRow
Row type returned from routines query
TableRow
Row type returned from tables query

Traits

DbIntrospector
Trait for database introspection

Functions

parse_columns_json
Parse a JSON string into a vector of columns for a table
parse_params_json
Parse a JSON string into a vector of routine parameters
parse_return_type_json
Parse a JSON string into a return type