pub enum AnyRelationship {
ForeignKey(Relationship),
Computed(ComputedRelationship),
}Expand description
Either a FK relationship or computed relationship
Used to represent any type of relationship in a unified way.
Variants
ForeignKey(Relationship)
Standard foreign key relationship
Computed(ComputedRelationship)
Function-based computed relationship
Implementations
Sourceimpl AnyRelationship
impl AnyRelationship
Sourcepub fn table(&self) -> &QualifiedIdentifier
pub fn table(&self) -> &QualifiedIdentifier
Get the source table
Sourcepub fn foreign_table(&self) -> &QualifiedIdentifier
pub fn foreign_table(&self) -> &QualifiedIdentifier
Get the target/foreign table
Sourcepub fn is_computed(&self) -> bool
pub fn is_computed(&self) -> bool
Check if this is a computed relationship
Sourcepub fn as_fk(&self) -> Option<&Relationship>
pub fn as_fk(&self) -> Option<&Relationship>
Get the foreign key relationship if this is one
Sourcepub fn as_computed(&self) -> Option<&ComputedRelationship>
pub fn as_computed(&self) -> Option<&ComputedRelationship>
Get the computed relationship if this is one