pub struct ComputedField {
pub function: QualifiedIdentifier,
pub return_type: CompactString,
pub returns_set: bool,
}Expand description
Computed field metadata
Represents a function that can be used as a computed field on a table. The function takes a table row type as the first parameter and returns a scalar value.
Fields
function: QualifiedIdentifierFunction qualified identifier
return_type: CompactStringReturn type (scalar)
returns_set: boolWhether function returns a set