pub fn stream_json_array(body: String) -> BodyExpand description
Stream a JSON array by parsing the body string and streaming it chunk by chunk.
This is useful for large result sets where we want to avoid loading the entire JSON array into memory at once.