Database introspection trait
This module defines a trait for database introspection that can be mocked in tests. This allows unit testing schema cache logic without a real database.
Structs
- Column
Json - JSON structure for column data
- Computed
Field Row - Row type returned from computed fields query
- Param
Json - JSON structure for routine parameter data
- Relationship
Row - Row type returned from relationships query
- Return
Type Json - JSON structure for return type data
- Routine
Row - Row type returned from routines query
- Table
Row - Row type returned from tables query
Traits
- DbIntrospector
- Trait for database introspection
Functions
- parse_
columns_ json - Parse a JSON string into a vector of columns for a table
- parse_
params_ json - Parse a JSON string into a vector of routine parameters
- parse_
return_ type_ json - Parse a JSON string into a return type