Computed fields introspection query
Query for detecting functions that can be used as computed fields. These are functions that take a table row type as the first parameter and return a scalar value (not a composite type).
Constants
- COMPUTED_
FIELDS_ QUERY - SQL query to find computed field functions